<?php
/**
 * @file
 * Contains \Drupal\mediasync\Form\MediasyncSettingsForm.
 */
namespace Drupal\mediasync\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure example settings for this site.
 */
class MediasyncSettingsForm extends ConfigFormBase {

  /** 
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'mediasync.settings';

  /** 
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'mediasync_admin_settings';
  }

  /** 
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /** 
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $form['folder'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Folder to sync'),
      '#default_value' => $config->get('folder'),
    ];  

    $form['type'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Filetype => Media type'),
      '#default_value' => $config->get('type'),
    ];  

    return parent::buildForm($form, $form_state);
  }

  /** 
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable(static::SETTINGS)
      ->set('folder', $form_state->getValue('folder'))
      ->set('type', $form_state->getValue('type'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}